@@ -4,7 +4,7 @@ require Exporter;
 @EXPORT_OK = qw/to_singular is_plural/;
 use warnings;
 use strict;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 # Irregular plurals.
 
@@ -19,6 +19,7 @@ our $VERSION = '0.16';
 
 my %irregular = (qw/
     analyses analysis
+    brethren brother
     children child
     corpora corpus
     craftsmen craftsman
@@ -39,6 +40,7 @@ my %irregular = (qw/
     neuroses neurosis
     nuclei nucleus
     oases oasis
+    oxen ox
     pence penny
     people person
     phenomena phenomenon
@@ -88,7 +90,6 @@ my %plural = (
 # A store of words which are the same in both singular and plural.
 
 my @no_change = qw/
-                      clothes
                       deer
                       ides
                       fish
@@ -109,65 +110,71 @@ my @no_change = qw/
 # http://virtuallinguist.typepad.com/the_virtual_linguist/2009/10/singular-nouns-ending-in-s.html
 
 my @not_plural = (qw/
-			Charles
-			Gonzales 
-			Hades 
-			Hercules 
-			Hermes 
-			Holmes 
-			Hughes 
-			Ives 
-			Jacques 
-			James 
-			Keyes 
-			Mercedes 
-			Naples 
-			Oates 
-			Raines 
-			Texas
-			athletics
-			bogus
-			bus
-			cactus
-			cannabis
-			chaos
-			citrus
-			corps
-			corpus
-			devious
-			dias
-			famous
-			hippopotamus
-			homunculus
-			iris
-			lens
-			mathematics
-			metaphysics
-			metropolis
-			mews
-			minus
-			miscellaneous
-			molasses
-			mrs
-			narcissus
-			news
-			octopus
-			ourselves
-			papyrus
-			perhaps
-			physics
-			platypus
-			plus
-			previous
-			pus
-			sometimes
-			stylus
-			themselves
-			this
-			thus
-			various
-			yes
-		    /);
+Aries
+Charles
+Gonzales 
+Hades 
+Hercules 
+Hermes 
+Holmes 
+Hughes 
+Ives 
+Jacques 
+James 
+Keyes 
+Mercedes 
+Naples 
+Oates 
+Raines 
+Texas
+athletics
+bogus
+bus
+cactus
+cannabis
+caries
+chaos
+citrus
+clothes
+corps
+corpus
+devious
+dias
+facies
+famous
+hippopotamus
+homunculus
+iris
+lens
+mathematics
+metaphysics
+metropolis
+mews
+minus
+miscellaneous
+molasses
+mrs
+narcissus
+news
+octopus
+ourselves
+papyrus
+perhaps
+physics
+platypus
+plus
+previous
+pus
+rabies
+scabies
+sometimes
+stylus
+themselves
+this
+thus
+various
+yes
+/);
 
 my %not_plural;
 
@@ -183,18 +190,18 @@ my %not_plural;
 # perl -n -e 'print if /oe$/' < /usr/share/dict/words
 
 my @oes = (qw/
-		 canoes
-		 does
-		 foes
-		 gumshoes
-		 horseshoes
-		 oboes
-		 shoes
-		 snowshoes
-		 throes
-                 hoes
-                 toes
-             /);
+canoes
+does
+foes
+gumshoes
+hoes
+horseshoes
+oboes
+shoes
+snowshoes
+throes
+toes
+/);
 
 my %oes;
 
@@ -220,7 +227,7 @@ my @ies = (qw/
 Aussies
 Valkryies
 aunties
-bogie
+bogies
 brownies
 calories
 charlies
@@ -230,7 +237,7 @@ curies
 cuties
 dies
 genies
-goalie
+goalies
 kilocalories
 lies
 magpies
